nltk.sentiment package
======================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.sentiment.sentiment_analyzer
   nltk.sentiment.util
   nltk.sentiment.vader

Module contents
---------------

.. automodule:: nltk.sentiment
   :members:
   :undoc-members:
   :show-inheritance:
